<?php
/*
Module Name: Luxe Theme
Description: Custom theme for Eykegai CRM
Version: 1.0
Author: Eykegai
Author URI: https://eykegai.com
Requires at least: 1.0
*/

defined('BASEPATH') or exit('No direct script access allowed');

hooks()->add_action('app_admin_head', 'perfex_luxe_theme_head_component');
hooks()->add_action('app_admin_footer', 'perfex_luxe_theme_footer_js__component');
hooks()->add_action('app_admin_authentication_head', 'perfex_luxe_theme_staff_login');
hooks()->add_action('app_customers_head', 'perfex_app_client_dark_head_includes');
hooks()->add_action('app_customers_footer', 'perfex_luxe_theme_customers_footer_js__component');

/**
 * Theme customers login includes
 * @return stylesheet / script
 */
function perfex_luxe_theme_staff_login()
{
    echo '<link href="' . base_url('modules/perfex_luxe_theme/assets/css/theme_styles.css') . '"  rel="stylesheet" type="text/css" >';
    echo '<script src="' . module_dir_url('perfex_luxe_theme', 'assets/js/sign_in.js') . '"></script>';
}

/**
 * Theme clients footer includes
 * @return stylesheet
 */
function perfex_app_client_dark_head_includes()
{
    echo '<link href="' . base_url('modules/perfex_luxe_theme/assets/css/theme_styles.css') . '"  rel="stylesheet" type="text/css" >';
}

/**
 * Injects theme CSS
 * @return null
 */
function perfex_luxe_theme_head_component()
{
    echo '<link href="' . base_url('modules/perfex_luxe_theme/assets/css/theme_styles.css') . '"  rel="stylesheet" type="text/css" >';
}

/**
 * Injects theme js components in footer
 * @return null
 */
function perfex_luxe_theme_footer_js__component()
{
    echo '<script src="' . module_dir_url('perfex_luxe_theme', 'assets/js/feather.min.js') . '"></script>';
    echo '<script src="' . module_dir_url('perfex_luxe_theme', 'assets/js/main.js') . '"></script>';
}

/**
 * Injects customers theme js components in footer
 * @return null
 */
function perfex_luxe_theme_customers_footer_js__component()
{
    echo '<script src="' . module_dir_url('perfex_luxe_theme', 'assets/js/clients.js') . '"></script>';
}


/**
 * Injects link fullscreen and mode dark
 * @return null
 */

hooks()->add_action('admin_navbar_start', 'perfex_luxe_theme_custom_menu_header');

function perfex_luxe_theme_custom_menu_header()
{
    if(get_option('perfex_luxe_theme_show_dark')){
        echo '<li class="icon mode" data-placement="bottom" data-toggle="tooltip" data-original-title="Dark"><a href="#"><i class="fa fa-moon-o"></i></a></li>';
    }
    if(get_option('perfex_luxe_theme_show_fullscreen')){
        echo '<li class="icon full_screen" data-placement="bottom" data-toggle="tooltip" data-original-title="Full Screen"><a href="#"><i class="feather_full"></i></a></li>';
    }
}

/**
 * Add logo Dark
 * @return null
 */
hooks()->add_action('after_body_start', 'perfex_luxe_theme_custom_logo');

function perfex_luxe_theme_custom_logo()
{
    get_dark_company_logo('admin', 'dark', 'dark');
}

/**
 * Add logo White to admin auth
 * @return null
 */ 
hooks()->add_action('app_admin_authentication_head', 'perfex_luxe_theme_custom_logo_admin');

function perfex_luxe_theme_custom_logo_admin()
{
    get_company_logo('admin','white', '');
}

/**
 * Add logo White to user auth
 * @return null
 */
hooks()->add_action('customers_after_body_start', 'perfex_luxe_theme_custom_logo_user');

function perfex_luxe_theme_custom_logo_user()
{
    get_company_logo('admin','navbar-brand white', '');
}

/**
 * Add Loading styles
 * @return null
 */
hooks()->add_filter('admin_body_class', 'perfex_luxe_theme_admin_body_class');

function perfex_luxe_theme_admin_body_class($classes)
{
    $classes[] = 'loading';
    return $classes;
}

/**
 * Actions for inject the custom styles
 */

hooks()->add_action('app_admin_head', 'perfex_luxe_theme_style_admin_head');
hooks()->add_action('app_customers_head', 'perfex_luxe_theme_style_admin_head');
hooks()->add_action('app_admin_authentication_head', 'perfex_luxe_theme_style_admin_head');
hooks()->add_filter('admin_body_class', 'perfex_luxe_body_class');
 
function perfex_luxe_body_class($classes)
{
    if (get_option('perfex_luxe_theme_style_dark')) { 
        $classes[] = 'dark-only';
    }else{
        if (($key = array_search('dark-only', $classes)) !== false) {
            unset($classes[$key]);
        }
    }
 
    switch (get_option('perfex_luxe_theme_default_theme')){
        case '1':
            $classes[] = 'header_color';
            break;
        case '2':
            $classes[] = 'sidebar_color';
            break;
        case '3':
            $classes[] = 'sidebar_color';
            $classes[] = 'header_color';
            break;
        default:
            if (($key = array_search('sidebar_color', $classes)) !== false) {
                unset($classes[$key]);
            }
            if (($key = array_search('header_color', $classes)) !== false) {
                unset($classes[$key]);
            }
    }
 
    return $classes;
}
function perfex_luxe_theme_style_admin_head()
{
    luxe_theme_style_render(['customize_theme']);
}
 
/**
 * Defined styling areas for the luxe theme style feature
 * Those string are not translated to keep the language file neat
 * @param  string $type
 * @return array
 */
function luxe_theme_get_styling_areas($type = 'customize_theme')
{
    $areas = [
        'customize_theme' => [
            [
                'name'                 => _l('luxe_theme_primary_color'),
                'id'                   => 'luxe-primary-color',
                'css_var'              => 'color-primary',
            ],
            [
                'name'                 => _l('luxe_theme_text_nav_color'),
                'id'                   => 'luxe-text-nav-color',
                'css_var'              => 'text-nav-color',
            ],
             
        ],
    ];
 
    $CI = & get_instance();
    $areas = hooks()->apply_filters('luxe_theme_get_styling_areas', $areas);
 
    if (!is_array($type)) {
        return $areas[$type];
    }
 
    $_areas = [];
    foreach ($type as $t) {
        $_areas[] = $areas[$t];
    }
 
    return $_areas;
}
 
function luxe_theme_get_applied_styling_area()
{
    $theme_style = get_option('perfex_luxe_theme_style');
    if ($theme_style == '') {
        return [];
    }
    $theme_style = json_decode($theme_style);

    return $theme_style;
}
 
function luxe_hex2rgb($hex){
    $hex = strtolower($hex);
    list($r, $g, $b) = sscanf($hex, '#%2x%2x%2x');
    $rgb = new stdClass();
    $rgb->r = $r;
    $rgb->g = $g;
    $rgb->b = $b;
    return $rgb;
}
 
function luxe_theme_style_render($type)
{
    $theme_style = luxe_theme_get_applied_styling_area();
    $styling_areas = luxe_theme_get_styling_areas($type);

    foreach ($styling_areas as $type => $area) {
        foreach ($area as $_area) {
            foreach ($theme_style as $applied_style) {
                if ($applied_style->id == $_area['id']) {
                    $color_css = '--' .$_area['css_var'];
                    $color = $applied_style->color;
                    $color_rgb = luxe_hex2rgb($color);
                    $color_rgb = $color_rgb->r . ',' . $color_rgb->g . ',' . $color_rgb->b;
                    echo '<style class="style_' . $_area['id'] . '">' . PHP_EOL;
                    echo ':root {' . PHP_EOL . $color_css . ':' . $color . ';' . $color_css . '-rgb:' . $color_rgb . ';' . PHP_EOL .'}'. PHP_EOL;
                    echo '</style>' . PHP_EOL;
                }
            }
        }
    }

    $custom_css = get_option('perfex_luxe_theme_custom_css');
    if (!empty($custom_css)) {
        echo '<style id="style_perfex_luxe_theme_custom_css">' . PHP_EOL;
        if (!empty($custom_css)) {
            $custom_css = clear_textarea_breaks($custom_css);
            echo $custom_css . PHP_EOL;
        }
        echo '</style>' . PHP_EOL;
    }
}
 
function luxe_theme_get_custom_style_values($type, $selector)
{
    $value = '';
    $theme_style = luxe_theme_get_applied_styling_area();
    $styling_areas = luxe_theme_get_styling_areas($type);
    foreach ($styling_areas as $area) {
        if ($area['id'] == $selector) {
            foreach ($theme_style as $applied_style) {
                if ($applied_style->id == $selector) {
                    $value = $applied_style->color;

                    break;
                }
            }
        }
    }

    return $value;
}
 
function luxe_theme_render_styling_picker($id, $value, $target, $css, $additional = '')
{
    echo '<div class="input-group mbot15 colorpicker-component" data-target="' . $target . '" data-css="' . $css . '" data-additional="' . $additional . '">
    <input type="text" value="' . $value . '" data-id="' . $id . '" class="form-control" />
    <span class="input-group-addon"><i></i></span>
    </div>';
}