<?php

defined('BASEPATH') or exit('No direct script access allowed');

/*
Module Name: Luxe Theme
Description: Custom Theme for Eykegai CRM
Version: 1.0.0
Author: Eykegai
Author URI: https://eykegai.com
Requires at least: 1.0.0
*/

define('PERFEX_LUXE_THEME_MODULE_NAME', 'perfex_luxe_theme');
define('PERFEX_LUXE_THEME_CSS', module_dir_path(PERFEX_LUXE_THEME_MODULE_NAME, 'assets/css/theme_styles.css'));

$CI = &get_instance();

/**
 * Register the activation module
 */
register_activation_hook(PERFEX_LUXE_THEME_MODULE_NAME, 'perfex_luxe_theme_activation_hook');

/**
 * The activation function
 */
function perfex_luxe_theme_activation_hook()
{
	require(__DIR__ . '/install.php');
}

/**
 * Register module language files
 */
register_language_files(PERFEX_LUXE_THEME_MODULE_NAME, ['perfex_luxe_theme']);

/**
 * Load the module helper
 */
$CI->load->helper(PERFEX_LUXE_THEME_MODULE_NAME . '/perfex_theme_luxe');

/**
 * Actions for creating luxe setting link and menu
 */
hooks()->add_filter('module_perfex_luxe_theme_action_links', 'module_perfex_luxe_theme_action_links');
hooks()->add_action('admin_init', 'perfex_luxe_theme_style_init_menu_items');

/**
 * Add additional settings for this module in the module list area
 * @param  array $actions current actions
 * @return array
 */
function module_perfex_luxe_theme_action_links($actions)
{
    $actions[] = '<a href="' . admin_url('perfex_luxe_theme/style') . '">' . _l('settings') . '</a>';
    return $actions;
}

/**
 * Init perfex luxe theme style module menu items in setup in admin_init hook
 * @return null
 */
function perfex_luxe_theme_style_init_menu_items()
{
    if (is_admin()) {
        $CI = &get_instance();
        /**
         * If the logged in user is administrator, add custom menu in Setup
         */
        $CI->app_menu->add_setup_menu_item('perfex-luxe-theme-style', [
            'href'     => admin_url('perfex_luxe_theme/style'),
            'name'     => _l('perfex_luxe_theme_style'),
            'position' => 65,
        ]);
    }
}